{
    "$graph": [
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "dockerPull": "mgrast/pipeline:4.03",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "stdout": "consensus.log",
            "stderr": "consensus.error",
            "inputs": [
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "doc": "max number of bps to process [default 100]",
                    "inputBinding": {
                        "prefix": "--bp_max"
                    },
                    "id": "#consensus.tool.cwl/basepairs"
                },
                {
                    "type": "string",
                    "doc": "Output file.",
                    "inputBinding": {
                        "prefix": "--output"
                    },
                    "id": "#consensus.tool.cwl/output"
                },
                {
                    "type": "File",
                    "doc": "Input file, sequence (fasta/fastq).",
                    "inputBinding": {
                        "prefix": "--input"
                    },
                    "id": "#consensus.tool.cwl/sequences"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "--stats"
                    },
                    "id": "#consensus.tool.cwl/stats"
                }
            ],
            "baseCommand": [
                "consensus.py"
            ],
            "arguments": [
                {
                    "valueFrom": "--verbose"
                },
                {
                    "prefix": "--type",
                    "valueFrom": "${\n    return inputs.sequences.basename.split(\".\").slice(-1)[0]\n} \n"
                }
            ],
            "id": "#consensus.tool.cwl",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output)"
                    },
                    "id": "#consensus.tool.cwl/consensus"
                },
                {
                    "type": "File",
                    "id": "#consensus.tool.cwl/error",
                    "outputBinding": {
                        "glob": "consensus.error"
                    }
                },
                {
                    "type": "File",
                    "id": "#consensus.tool.cwl/summary",
                    "outputBinding": {
                        "glob": "consensus.log"
                    }
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "dockerPull": "mgrast/pipeline:4.03",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "stdout": "drisee.log",
            "stderr": "drisee.error",
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#drisee.tool.cwl/sequences"
                }
            ],
            "baseCommand": [
                "drisee"
            ],
            "arguments": [
                {
                    "valueFrom": "drisee.stats",
                    "position": 2
                },
                "--verbose",
                "--filter_seq",
                {
                    "valueFrom": "$(runtime.cores)",
                    "prefix": "--processes"
                },
                {
                    "valueFrom": "$(runtime.tmpdir)",
                    "prefix": "--tmp_dir"
                },
                {
                    "prefix": "--seq_type",
                    "valueFrom": "${\n   return inputs.sequences.basename.split(\".\").slice(-1)[0]\n  } \n"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#drisee.tool.cwl/error",
                    "outputBinding": {
                        "glob": "drisee.error"
                    }
                },
                {
                    "type": "File",
                    "id": "#drisee.tool.cwl/info",
                    "outputBinding": {
                        "glob": "drisee.log"
                    }
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "drisee.stats"
                    },
                    "id": "#drisee.tool.cwl/stats"
                }
            ],
            "id": "#drisee.tool.cwl"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "dockerPull": "mgrast/pipeline:4.03",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "stdout": "format_qc_stats.stats",
            "stderr": "format_qc_stats.error",
            "inputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "doc": "consensus stat file",
                    "inputBinding": {
                        "prefix": "-consensus"
                    },
                    "id": "#format_qc_stats.tool.cwl/consensus"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "doc": "coverage stat file",
                    "inputBinding": {
                        "prefix": "-coverage"
                    },
                    "id": "#format_qc_stats.tool.cwl/coverage"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "doc": "drisee info file",
                    "inputBinding": {
                        "prefix": "-drisee_info"
                    },
                    "id": "#format_qc_stats.tool.cwl/driseeInfo"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "doc": "drisee stat file",
                    "inputBinding": {
                        "prefix": "-drisee_stat"
                    },
                    "id": "#format_qc_stats.tool.cwl/driseeStat"
                },
                {
                    "type": {
                        "type": "array",
                        "items": {
                            "type": "record",
                            "fields": [
                                {
                                    "name": "#format_qc_stats.tool.cwl/kmer/length",
                                    "type": "int"
                                },
                                {
                                    "name": "#format_qc_stats.tool.cwl/kmer/file",
                                    "type": "File"
                                }
                            ]
                        }
                    },
                    "doc": "kmer record array",
                    "id": "#format_qc_stats.tool.cwl/kmer"
                },
                {
                    "type": "string",
                    "doc": "output prefix = ${output_prefix}.seq.bins, ${output_prefix}.seq.stats",
                    "inputBinding": {
                        "prefix": "-out_prefix"
                    },
                    "id": "#format_qc_stats.tool.cwl/outPrefix"
                }
            ],
            "baseCommand": [
                "format_qc_stats.pl"
            ],
            "arguments": [
                {
                    "prefix": "-kmer_lens",
                    "valueFrom": "${\n    return inputs.kmer.map( \n        function(r){ return r.length }\n    ).join();\n}\n"
                },
                {
                    "prefix": "-kmer_stats",
                    "valueFrom": "${\n    return inputs.kmer.map( \n        function(r){ return r.file.path }\n    ).join();\n}\n"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#format_qc_stats.tool.cwl/error",
                    "outputBinding": {
                        "glob": "format_qc_stats.error"
                    }
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.outPrefix).qc.stats"
                    },
                    "id": "#format_qc_stats.tool.cwl/stats"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.outPrefix).qc.summary"
                    },
                    "id": "#format_qc_stats.tool.cwl/summary"
                }
            ],
            "id": "#format_qc_stats.tool.cwl"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "dockerPull": "mgrast/pipeline:4.03",
                    "class": "DockerRequirement"
                }
            ],
            "stdout": "format_seq_stats.stats",
            "stderr": "format_seq_stats.error",
            "inputs": [
                {
                    "type": "string",
                    "doc": "output prefix, e.g. ${output_prefix}.seq.bins, ${output_prefix}.seq.stats",
                    "inputBinding": {
                        "prefix": "-out_prefix"
                    },
                    "id": "#format_seq_stats.tool.cwl/output_prefix"
                },
                {
                    "type": "File",
                    "doc": "gc bin file",
                    "inputBinding": {
                        "prefix": "-seq_gc"
                    },
                    "id": "#format_seq_stats.tool.cwl/sequence_gc"
                },
                {
                    "type": "File",
                    "doc": "len bin file",
                    "inputBinding": {
                        "prefix": "-seq_lens"
                    },
                    "id": "#format_seq_stats.tool.cwl/sequence_lengths"
                },
                {
                    "doc": "stats tabbed file",
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-seq_stat"
                    },
                    "id": "#format_seq_stats.tool.cwl/sequence_stats"
                }
            ],
            "baseCommand": [
                "format_seq_stats.pl"
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_prefix).seq.bins"
                    },
                    "id": "#format_seq_stats.tool.cwl/bins"
                },
                {
                    "type": "File",
                    "id": "#format_seq_stats.tool.cwl/error",
                    "outputBinding": {
                        "glob": "format_seq_stats.error"
                    }
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_prefix).seq.stats"
                    },
                    "id": "#format_seq_stats.tool.cwl/stats"
                }
            ],
            "id": "#format_seq_stats.tool.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "calcualate kmer bins",
            "doc": "Script to use jellyfish to get kmer information\nInput:\\ fasta/fastq file\nOutput:\\ kmer information, one of:\\\n    1. hash:\\ binary hash of counts\n    2. stats:\\ summary stats\n    3. dump:\\ profile (kmer seq - count)\n    4. histo:\\ histogram (count - abundance)\n    5. histo ranked:\\ count, abundance, count*abundance, reverse-sum(abundance), reverse-sum(count*abundance), ratio-to-largest\n",
            "hints": [
                {
                    "dockerPull": "mgrast/pipeline:4.03",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "stdout": "kmer-tool.log",
            "stderr": "kmer-tool.error",
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Output format, one of [hash, stats, dump, histo], default histo",
                    "default": "histo",
                    "inputBinding": {
                        "prefix": "--format"
                    },
                    "id": "#kmer-tool.tool.cwl/format"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "doc": "Length of kmer to use, eg. 6 or 15",
                    "default": 6,
                    "inputBinding": {
                        "prefix": "--length"
                    },
                    "id": "#kmer-tool.tool.cwl/length"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "doc": "Maximum size (in Gb) to count, files larger are split, default 10.0",
                    "default": 10.0,
                    "inputBinding": {
                        "prefix": "--max"
                    },
                    "id": "#kmer-tool.tool.cwl/maxSize"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Prefix for output file(s)",
                    "default": "qc",
                    "id": "#kmer-tool.tool.cwl/prefix"
                },
                {
                    "type": "File",
                    "doc": "Input file, sequence (fasta/fastq) or binary count hash (hash).",
                    "inputBinding": {
                        "prefix": "--input"
                    },
                    "id": "#kmer-tool.tool.cwl/sequences"
                }
            ],
            "baseCommand": [
                "kmer-tool"
            ],
            "arguments": [
                "--ranked",
                {
                    "prefix": "--procs",
                    "valueFrom": "$(runtime.cores)"
                },
                {
                    "prefix": "--type",
                    "valueFrom": "${\n    return inputs.sequences.basename.split(\".\").slice(-1)[0]\n}\n"
                },
                {
                    "prefix": "--tmpdir",
                    "valueFrom": "$(runtime.outdir)"
                },
                {
                    "prefix": "--output",
                    "valueFrom": "$(inputs.prefix).kmer.$(inputs.length).stats"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#kmer-tool.tool.cwl/error",
                    "outputBinding": {
                        "glob": "kmer-tool.error"
                    }
                },
                {
                    "type": {
                        "type": "record",
                        "label": "none",
                        "fields": [
                            {
                                "name": "#kmer-tool.tool.cwl/stats/length",
                                "type": "int",
                                "outputBinding": {
                                    "outputEval": "$(inputs.length)"
                                }
                            },
                            {
                                "name": "#kmer-tool.tool.cwl/stats/file",
                                "type": "File",
                                "outputBinding": {
                                    "glob": "$(inputs.prefix).kmer.$(inputs.length).stats"
                                }
                            }
                        ]
                    },
                    "id": "#kmer-tool.tool.cwl/stats"
                },
                {
                    "type": "File",
                    "id": "#kmer-tool.tool.cwl/summary",
                    "outputBinding": {
                        "glob": "kmer-tool.log"
                    }
                }
            ],
            "id": "#kmer-tool.tool.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "sequence statistics",
            "doc": "Calculate statistics for fasta files.\nOutput fields:\\\n  bp_count\n  sequence_count\n  average_length\n  standard_deviation_length\n  length_min\n  length_max\n  average_gc_content\n  standard_deviation_gc_content\n  average_gc_ratio\n  standard_deviation_gc_ratio\n  ambig_char_count\n  ambig_sequence_count\n  average_ambig_chars\n  sequence_type\n",
            "hints": [
                {
                    "dockerPull": "mgrast/pipeline:4.03",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "stdout": "seq_length_stats.stats",
            "stderr": "seq_length_stats.error",
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Fast stats, length and count only, for protein sequences",
                    "inputBinding": {
                        "prefix": "--fast"
                    },
                    "id": "#seq_length_stats.tool.cwl/fast"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Filename to place gc bins",
                    "inputBinding": {
                        "prefix": "--gc_percent_bin"
                    },
                    "id": "#seq_length_stats.tool.cwl/gcBin"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Ignore commas in header ID",
                    "inputBinding": {
                        "prefix": "--ignore_comma"
                    },
                    "id": "#seq_length_stats.tool.cwl/ignoreComma"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Filename to place length bins [default is no output]",
                    "inputBinding": {
                        "prefix": "--length_bin"
                    },
                    "id": "#seq_length_stats.tool.cwl/lenBin"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Output stats in json format, default is tabbed text",
                    "inputBinding": {
                        "prefix": "--json"
                    },
                    "id": "#seq_length_stats.tool.cwl/outJson"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Output stats file name, if not called prints to STDOUT",
                    "inputBinding": {
                        "prefix": "--output"
                    },
                    "id": "#seq_length_stats.tool.cwl/outName"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "doc": "max number of seqs to process (for kmer entropy)",
                    "default": 100000,
                    "inputBinding": {
                        "prefix": "--seq_max"
                    },
                    "id": "#seq_length_stats.tool.cwl/seqMax"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Guess sequence type [wgs|amplicon] from kmer entropy",
                    "inputBinding": {
                        "prefix": "--seq_type"
                    },
                    "id": "#seq_length_stats.tool.cwl/seqType"
                },
                {
                    "type": "File",
                    "doc": "Input file, sequence (fasta/fastq)",
                    "inputBinding": {
                        "prefix": "--input"
                    },
                    "id": "#seq_length_stats.tool.cwl/sequences"
                }
            ],
            "baseCommand": [
                "seq_length_stats.py"
            ],
            "arguments": [
                {
                    "prefix": "--type",
                    "valueFrom": "${\n    return inputs.sequences.basename.split(\".\").slice(-1)[0]\n}\n"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#seq_length_stats.tool.cwl/error",
                    "outputBinding": {
                        "glob": "seq_length_stats.error"
                    }
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.gcBin)"
                    },
                    "id": "#seq_length_stats.tool.cwl/gcBinOut"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.lenBin)"
                    },
                    "id": "#seq_length_stats.tool.cwl/lenBinOut"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.outName)"
                    },
                    "id": "#seq_length_stats.tool.cwl/statOut"
                },
                {
                    "type": "File",
                    "id": "#seq_length_stats.tool.cwl/stdout",
                    "outputBinding": {
                        "glob": "seq_length_stats.stats"
                    }
                }
            ],
            "id": "#seq_length_stats.tool.cwl"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#main/jobid"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "int"
                        }
                    ],
                    "default": [
                        6
                    ],
                    "id": "#main/kmerLength"
                },
                {
                    "type": "File",
                    "id": "#main/sequences"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/formatQcStats/stats",
                    "id": "#main/qcStatFile"
                },
                {
                    "type": "File",
                    "outputSource": "#main/formatQcStats/summary",
                    "id": "#main/qcSummaryFile"
                },
                {
                    "type": "File",
                    "outputSource": "#main/formatSequenceStats/bins",
                    "id": "#main/seqBinFile"
                },
                {
                    "type": "File",
                    "outputSource": "#main/formatSequenceStats/stats",
                    "id": "#main/seqStatFile"
                }
            ],
            "steps": [
                {
                    "run": "#consensus.tool.cwl",
                    "label": "Nucleotide Histogram",
                    "doc": "Compute nucleotide histogram for all reads",
                    "in": [
                        {
                            "source": "#main/jobid",
                            "valueFrom": "$(self).075.consensus.stats",
                            "id": "#main/consensus/output"
                        },
                        {
                            "source": "#main/sequences",
                            "id": "#main/consensus/sequences"
                        },
                        {
                            "source": "#main/sequenceStats/statOut",
                            "id": "#main/consensus/stats"
                        }
                    ],
                    "out": [
                        "#main/consensus/summary",
                        "#main/consensus/consensus"
                    ],
                    "id": "#main/consensus"
                },
                {
                    "run": "#drisee.tool.cwl",
                    "in": [
                        {
                            "source": "#main/sequences",
                            "id": "#main/drisee/sequences"
                        }
                    ],
                    "out": [
                        "#main/drisee/info",
                        "#main/drisee/stats"
                    ],
                    "id": "#main/drisee"
                },
                {
                    "run": "#format_qc_stats.tool.cwl",
                    "in": [
                        {
                            "source": "#main/consensus/consensus",
                            "id": "#main/formatQcStats/consensus"
                        },
                        {
                            "source": "#main/drisee/info",
                            "id": "#main/formatQcStats/driseeInfo"
                        },
                        {
                            "source": "#main/drisee/stats",
                            "id": "#main/formatQcStats/driseeStat"
                        },
                        {
                            "source": "#main/kmer/stats",
                            "id": "#main/formatQcStats/kmer"
                        },
                        {
                            "source": "#main/jobid",
                            "valueFrom": "$(self).075.qc",
                            "id": "#main/formatQcStats/outPrefix"
                        }
                    ],
                    "out": [
                        "#main/formatQcStats/stats",
                        "#main/formatQcStats/summary"
                    ],
                    "id": "#main/formatQcStats"
                },
                {
                    "run": "#format_seq_stats.tool.cwl",
                    "in": [
                        {
                            "source": "#main/jobid",
                            "valueFrom": "$(self).075.qc",
                            "id": "#main/formatSequenceStats/output_prefix"
                        },
                        {
                            "source": "#main/sequenceStats/gcBinOut",
                            "id": "#main/formatSequenceStats/sequence_gc"
                        },
                        {
                            "source": "#main/sequenceStats/lenBinOut",
                            "id": "#main/formatSequenceStats/sequence_lengths"
                        },
                        {
                            "source": "#main/sequenceStats/statOut",
                            "id": "#main/formatSequenceStats/sequence_stats"
                        }
                    ],
                    "out": [
                        "#main/formatSequenceStats/stats",
                        "#main/formatSequenceStats/bins"
                    ],
                    "id": "#main/formatSequenceStats"
                },
                {
                    "run": "#kmer-tool.tool.cwl",
                    "scatter": "#main/kmer/length",
                    "scatterMethod": "dotproduct",
                    "in": [
                        {
                            "valueFrom": "histo",
                            "id": "#main/kmer/format"
                        },
                        {
                            "source": "#main/kmerLength",
                            "id": "#main/kmer/length"
                        },
                        {
                            "source": "#main/jobid",
                            "valueFrom": "$(self).075",
                            "id": "#main/kmer/prefix"
                        },
                        {
                            "source": "#main/sequences",
                            "id": "#main/kmer/sequences"
                        }
                    ],
                    "out": [
                        "#main/kmer/stats"
                    ],
                    "id": "#main/kmer"
                },
                {
                    "run": "#seq_length_stats.tool.cwl",
                    "in": [
                        {
                            "source": "#main/jobid",
                            "valueFrom": "$(self).075.gc.bin",
                            "id": "#main/sequenceStats/gcBin"
                        },
                        {
                            "source": "#main/jobid",
                            "valueFrom": "$(self).075.length.bin",
                            "id": "#main/sequenceStats/lenBin"
                        },
                        {
                            "source": "#main/jobid",
                            "valueFrom": "$(self).075.seq.stats",
                            "id": "#main/sequenceStats/outName"
                        },
                        {
                            "source": "#main/sequences",
                            "id": "#main/sequenceStats/sequences"
                        }
                    ],
                    "out": [
                        "#main/sequenceStats/statOut",
                        "#main/sequenceStats/lenBinOut",
                        "#main/sequenceStats/gcBinOut"
                    ],
                    "id": "#main/sequenceStats"
                }
            ],
            "id": "#main"
        }
    ],
    "cwlVersion": "v1.0"
}
